#!/bin/bash


#  slackbuild script for bbdb
# Author: Mark Tucker
# Created: Aug 12, 2004
# Changes:
#        Aug 12, 2004 - initial creation
#

#
#----------------------------------------------------------------------
umask 0022
#----------------------------------------
# Package variables
#----------------------------------------
source="bbdb-2.34.tar.gz"
pkgname="bbdb"
pkgver="2.34"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
# where the source archive is located
srcdir=`pwd`/SRC
thisfile=`pwd`/`basename $0`
# get working directory
workdir=`dirname $0`
if [ "$workdir" == "." ]; then
    workdir=`pwd`/$pkgname
    if [ ! -d $workdir ]; then
	echo Creating working directory $workdir ...
	mkdir -p $workdir
    fi
    echo Working directory is $workdir
    cd $workdir
    echo Changed directory to  `pwd`
fi
builddir=$workdir/$pkgname-$pkgver


# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source



cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS

#----------------------------------------
# configure 
#----------------------------------------
echo Running configure...
./configure --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    > $workdir/config.output 2>&1

if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/config.output
    echo Exiting...
    exit
fi

#----------------------------------------
# make
#----------------------------------------
echo Running make...
make > $workdir/make.output 2>&1
if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/make.output
    echo Exiting...
    exit
fi

#----------------------------------------
# Set target directory
#----------------------------------------
target=$workdir/target
if [ ! -d $target ]; then
    mkdir $target
fi

#----------------------------------------
# install
#----------------------------------------
echo Installing to $target ...
mkdir -p $target/usr/share/emacs/site-lisp
cp $builddir/lisp/*.el* $target/usr/share/emacs/site-lisp
mkdir -p $target/usr/info
cp $builddir/texinfo/bbdb.info $target/usr/info
gzip $target/usr/info/bbdb.info


echo finishing install...

# create do-inst.sh script
cat > $target/install/doinst.sh << END
#!/bin/sh

# Add the new info file to the info dir
install-info /usr/info/bbdb.info.gz /usr/info/dir
#
END

# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
   |-----handy-ruler------------------------------------------------------|
bbdb: $pkgname $pkgver
bbdb:
bbdb: The Insidious Big Brother Database (BBDB) is a contact management
bbdb: utility created by Jamie Zawinski for use with Emacs. It is tightly 
bbdb: integrated with several mail and news readers (see below), allowing 
bbdb: it to create database entries directly from mail and news messages. 
bbdb:
bbdb: 
bbdb: http://bbdb.sourceforge.net/
bbdb: 
bbdb: Packaged by Mark Tucker for Slackware 10.0
END

#----------------------------------------
# create documentation directory
#----------------------------------------
mkdir -p $target/usr/doc/$pkgname-$pkgver
cp $builddir/[A-Z]* $target/usr/doc/$pkgname-$pkgver/
chmod a+r $target/usr/doc/$pkgname-$pkgver/*
cp $thisfile $target/usr/doc/$pkgname-$pkgver/SlackPkg.sh
# 
cp -r $builddir/utils $target/usr/doc/$pkgname-$pkgver/
cp -r $builddir/bits $target/usr/doc/$pkgname-$pkgver/


#----------------------------------------
# fix group on bin directories.
#----------------------------------------
for i in bin sbin usr/sbin usr/bin usr/X11R6/bin
do
  if [ -d $target/$i ]; then
      echo Changing group on $target/$i
      chgrp -R bin $target/$i
  fi
done

#----------------------------------------
# check for uncompressed man pages
#----------------------------------------
for i in usr/man opt/kde/man usr/share/man usr/X11R6/man
do
  if [ -d $target/$i ]; then
      find $target/$i -name \*.[0-9] -exec gzip {} \;
  fi
done

# makepkg
cd $target
echo Creating package...
makepkg  -c n -l y $workdir/$package 

cd $workdir
echo DONE
exit

